function data = SBML_Test(modelobj)
%    RUNSIMULATION simulate SimBiology model, modelobj.
%   
%    Creation time: 23-Jan-2013 01:50 PM

% Get the active configuration set.
cs = getconfigset(modelobj, 'default');

% Run simulation.
data = sbiosimulate(modelobj, cs);

% Plot the results.
plottype_Time(data, {'[Sphingolipid model].X2','[Sphingolipid model].X1'});

% ----------------------------------------------------------
function plottype_Time(tobj, y)

if (length(tobj) > 1)
    sbioplot(tobj, @timeplotdata, [], y);
else
    timeplotdata(tobj, [], y);
end

%--------------------------------------------------------
function [handles, names] = timeplotdata(tobj, x, y)

handles = [];
for i=1:length(tobj)
    % Get the data from the next run.
    nexttobj = tobj(i);

    % Get the simulation data associated with the species
    % specified in y.
    if strcmpi(y, '<all>')
        [time, data, names] = getdata(nexttobj);
    else
        [time, data, names] = selectbyname(nexttobj, y);
    end

    % Error checking.
    if size(data,2) == 0
        error('Species specified do not exist.');
    end

    % Plot.
    hLine = plot(time, data);
    handles = [handles hLine];
end

% Label.
hold off;
xlabel('Time');
ylabel('States');
title('States versus Time');

if length(tobj) == 1
    leg = legend(names, 'Location', 'NorthEastOutside');
    set(leg, 'Interpreter', 'none');
end
